package com.totopia.server.user.repository;

import com.totopia.server.user.model.User;

import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.stereotype.Repository;

import java.util.Date;

@Repository
public interface UserRepository extends JpaRepository<User, Long> {
    // 회원 아이디로 조회
    User findByUsername(String userName) throws Exception;
    User findByEmail(String email) throws Exception;

    Page<User> findAllByNickname(String nickName, Pageable pageable) throws Exception;

    // 접속 제한 상태 유저 리스트
    Page<User>  findAllByBlockTrue(Pageable pageable) throws Exception;
    // 접속 제한 상태가 아닌 유저 리스트
    Page<User>  findAllByBlockFalse(Pageable pageable) throws Exception;
    // 어드민 유저 리스
    Page<User>  findAllByIsAdminTrue(Pageable pageable) throws Exception;
    // 패스워드 리셋이 트루인 유저 리스
    Page<User>  findAllByRequireResetTrue(Pageable pageable) throws Exception;
    // 어드민이 펄스이며, 활동중인 현재 회원 리스트
    Page<User>  findAllByIsAdminFalseAndActivationEquals(String activation, Pageable pageable) throws Exception;
    // 날짜 검색
    Page<User>  findAllByCreateDateBetween(Date starDate, Date endDate, Pageable pageable) throws Exception;
    Page<User>  findAllByUpdateDateBetween(Date starDate, Date endDate, Pageable pageable) throws Exception;
    Page<User>  findAllByLastResetTimeBetween(Date starDate, Date endDate, Pageable pageable) throws Exception;

    // 현재 날짜 이후 가입된 회원의 총 수 리턴
    Long countByCreateDateGreaterThanEqual(Date date) throws Exception;

    // 유저 그룹별 회원 리스트

    // 유저 소속별 회원 리스트

}
